Google Analytics 4 Measurement Protocol for Python
============================================================
An interface for the Google Analytics 4 Measurement Protocol.

This project is in *beta*. Please feel free to file issues for feature
requests or contact us directly at analytics-help@adswerve.com
__
